@@ -1,7 +1,7 @@
 """Generator
 
-Generates python classes based on an openapi.yaml file produced by the 
-bunder.py infrastructure.
+Given an openapi.yaml file that has been produced by the Bundler class in the
+bundler.py file the Generator class will produce an enhanced python ux file.
 
 TBD: 
 - packet slicing using constants
@@ -14,14 +14,17 @@ import os
 import subprocess
 import re
 import requests
+import pkgutil
+import importlib
 from jsonpath_ng import parse
+from .openapiartplugin import OpenApiArtPlugin
 
 MODELS_RELEASE = 'v0.3.3'
 
 
 class Generator(object):
     """Generates python classes based on an openapi.yaml file produced by the 
-    bunder.py infrastructure.
+    bundler.py infrastructure.
     """
     def __init__(self, openapi_filename, package_name, output_dir=None):
         self._generated_methods = []
@@ -31,16 +34,35 @@ class Generator(object):
         self.__python = os.path.normpath(sys.executable)
         self.__python_dir = os.path.dirname(self.__python)
         self._src_dir = output_dir
-        self._output_dir = self._src_dir
+        self._output_dir = os.path.join(output_dir, package_name)
+        if os.path.exists(self._output_dir) is False:
+            os.mkdir(self._output_dir)
         self._package_name = package_name
         self._output_file = package_name
         self._docs_dir = os.path.join(self._src_dir, '..', 'docs')
         self._clean()
         self._get_openapi_file()
+        # self._plugins = self._load_plugins()
+
+    def _load_plugins(self):
+        plugins = []
+        pkg_dir = os.path.dirname(__file__)
+        for (module_loader, name, ispkg) in pkgutil.iter_modules([pkg_dir]):
+            module_name = 'openapiart.' + name
+            importlib.import_module(module_name)
+            obj = sys.modules[module_name]
+            for dir_name in dir(obj):
+                if dir_name.startswith('_'):
+                    continue
+                dir_obj = getattr(obj, dir_name)
+                print(dir_obj)
+                if issubclass(dir_obj.__class__, OpenApiArtPlugin):
+                    plugins.append(dir_obj)
+        return plugins
 
     def _clean(self):
         """Clean the environment prior to file generation
-        - Remove any locally installed version of snappi
+        - Remove any locally installed version of 
         - Remove generated files
         - Leave infrastructure files that are prefixed with the word snappi
         """
@@ -52,17 +74,18 @@ class Generator(object):
             '--yes', 
             self._package_name
         ]
-        subprocess.Popen(process_args, shell=False).wait()
-        import fnmatch
-        for rootDir, subdirs, filenames in os.walk(self._src_dir):
-            if rootDir.endswith('tests'):
-                continue
-            for filename in fnmatch.filter(filenames, '*.py'):
-                try:
-                    if filename.startswith('snappi') is False:
-                        os.remove(os.path.join(rootDir, filename))
-                except OSError:
-                    print('Error deleting file %s' % filename)
+        # subprocess.Popen(process_args, shell=False).wait()
+        # os.rmdir(self._output_dir)
+        # import fnmatch
+        # for rootDir, subdirs, filenames in os.walk(self._src_dir):
+        #     if rootDir.endswith('tests'):
+        #         continue
+        #     for filename in fnmatch.filter(filenames, '*.py'):
+        #         try:
+        #             if filename.startswith('snappi') is False:
+        #                 os.remove(os.path.join(rootDir, filename))
+        #         except OSError:
+        #             print('Error deleting file %s' % filename)
 
     def _get_openapi_file(self):
         if self._openapi_filename is None:
@@ -98,8 +121,6 @@ class Generator(object):
         methods, factories = self._get_methods_and_factories()
         self._write_api_class(methods, factories)
         self._write_http_api_class(methods)
-        self._write_http_server(methods)
-        # self._write_api_factory()
         self._write_init()
         return self
 
@@ -225,7 +246,7 @@ class Generator(object):
             self._write(1, 'def __init__(self, location=None):')
             self._write(2, 'super(HttpApi, self).__init__(location=location)')
             self._write(
-                2, 'self._transport = HttpTransport(loation=self.location)'
+                2, 'self._transport = HttpTransport(location=self.location)'
             )
 
             for method in methods:
@@ -262,9 +283,6 @@ class Generator(object):
                 )
                 self._write(2, ')')
 
-    def _write_http_server(self, methods):
-        pass
-
     def _write_api_class(self, methods, factories):
         self._generated_classes.append('Api')
         with open(self._api_filename, 'a') as self._fid:
@@ -441,7 +459,7 @@ class Generator(object):
     def _get_choice_names(self, schema_object):
         choice_names = []
         if 'choice' in schema_object['properties']:
-            choice_names = schema_object['properties']['choice']['enum']
+            choice_names = schema_object['properties']['choice']['enum'].copy()
             choice_names.append('choice')
         return choice_names
 
@@ -742,14 +760,7 @@ class Generator(object):
         return paths
 
     def _write_data_properties(self, schema, classname, choice_tuples):
-        import_lines = []
         if len(choice_tuples) > 0:
-            for choice_tuple in choice_tuples:
-                if choice_tuple[2] is not None:
-                    import_line = self._get_import_from_ref(choice_tuple[2])
-                    if import_line not in import_lines:
-                        self._write(2, import_line)
-                        import_lines.append(import_line)
             choices = []
             for choice_tuple in choice_tuples:
                 choices.append(choice_tuple[0])
@@ -769,12 +780,6 @@ class Generator(object):
                 % classname)
 
         if 'properties' in schema:
-            for name, property in schema['properties'].items():
-                if '$ref' in property:
-                    import_line = self._get_import_from_ref(property['$ref'])
-                    if import_line not in import_lines:
-                        self._write(2, import_line)
-                        import_lines.append(import_line)
             for name, property in schema['properties'].items():
                 if len([item for item in choice_tuples if item[1] == name
                         ]) == 0 and name != 'choice':
@@ -858,15 +863,6 @@ class Generator(object):
             leaf = leaf[attr]
         return leaf
 
-    def _get_import_from_ref(self, ref):
-        filename = '_'.join(
-            ref.lower().split('#/components/schemas/')[-1].split('.')[0:-1])
-        classname = self._get_classname_from_ref(ref)
-        if len(filename) == 0:
-            filename = classname.lower()
-        return 'from abstract_open_traffic_generator.%s import %s' % (
-            filename, classname)
-
     def _get_classname_from_ref(self, ref):
         final_piece = ref.split('/')[-1]
         if '.' in final_piece:
